@@ -10,7 +10,7 @@
 # the full text of the license.
 
 # TODO: Address following pylint complaints
-# pylint: disable=invalid-name,missing-docstring
+# pylint: disable=missing-class-docstring,missing-function-docstring
 
 import configparser
 import contextlib
@@ -34,9 +34,9 @@ from problem_report import ProblemReport
 
 report_dir = os.environ.get("APPORT_REPORT_DIR", "/var/crash")
 core_dir = os.environ.get("APPORT_COREDUMP_DIR", "/var/lib/apport/coredump")
-max_corefiles_per_uid = 5
+MAX_COREFILES_PER_UID = 5
 
-_config_file = "~/.config/apport/settings"
+_CONFIG_FILE = "~/.config/apport/settings"
 
 SNAPD_SOCKET = "/run/snapd.socket"
 
@@ -49,13 +49,13 @@ class UHTTPConnection(http.client.HTTPConnection):
         http.client.HTTPConnection.__init__(self, "localhost")
         self.path = path
 
-    def connect(self):
+    def connect(self) -> None:
         sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
         sock.connect(self.path)
         self.sock = sock
 
 
-def allowed_to_report():
+def allowed_to_report() -> bool:
     """Check whether crash reporting is enabled."""
     if not os.access("/usr/bin/whoopsie", os.X_OK):
         return True
@@ -67,7 +67,7 @@ def allowed_to_report():
         return False
 
 
-def get_dbus_socket(dbus_addr):
+def get_dbus_socket(dbus_addr: str) -> str | None:
     """Extract the socket from a DBus address."""
     if not dbus_addr:
         return None
@@ -93,7 +93,7 @@ def get_dbus_socket(dbus_addr):
     return parts[1]
 
 
-def find_package_desktopfile(package):
+def find_package_desktopfile(package: str | None) -> str | None:
     """Return a package's .desktop file.
 
     If given package is installed and has a single .desktop file, return the
@@ -126,7 +126,7 @@ def find_package_desktopfile(package):
     return desktopfile
 
 
-def likely_packaged(file):
+def likely_packaged(file: str) -> bool:
     """Check whether the given file is likely to belong to a package.
 
     This is semi-decidable: A return value of False is definitive, a True value
@@ -507,7 +507,7 @@ def get_config(section, setting, default=None, path=None, boolean=False):
     if not path:
         # Properly handle dropped privileges
         homedir = pwd.getpwuid(os.geteuid())[5]
-        path = _config_file.replace("~", homedir)
+        path = _CONFIG_FILE.replace("~", homedir)
 
     config = _get_config_parser(path)
 
@@ -637,12 +637,11 @@ def get_core_path(
     return (core_name, core_path)
 
 
-def find_core_files_by_uid(uid):
+def find_core_files_by_uid(uid: int) -> list[tuple[str, float]]:
     """Search the core file directory for files that belong to a
-    specified uid. Returns a list of lists containing the filename and
+    specified uid. Returns a list of tuples containing the filename and
     the file modification time.
     """
-    uid = str(uid)
     core_files = []
     uid_files = []
 
@@ -651,9 +650,9 @@ def find_core_files_by_uid(uid):
 
     for f in core_files:
         try:
-            if f.split(".")[2] == uid:
+            if f.split(".")[2] == str(uid):
                 core_file_time = os.path.getmtime(os.path.join(core_dir, f))
-                uid_files.append([f, core_file_time])
+                uid_files.append((f, core_file_time))
         except (IndexError, FileNotFoundError):
             continue
     return uid_files
@@ -667,8 +666,8 @@ def clean_core_directory(uid: int) -> None:
     sorted_files = sorted(uid_files, key=operator.itemgetter(1))
 
     # Subtract a extra one to make room for the new core file
-    if len(uid_files) > max_corefiles_per_uid - 1:
-        for _ in range(len(uid_files) - max_corefiles_per_uid + 1):
+    if len(uid_files) > MAX_COREFILES_PER_UID - 1:
+        for _ in range(len(uid_files) - MAX_COREFILES_PER_UID + 1):
             os.remove(os.path.join(core_dir, sorted_files[0][0]))
             sorted_files.remove(sorted_files[0])
 
